@@ -12,10 +12,10 @@ qx.Class.define("callbackery.ui.plugin.Action", {
     extend : qx.ui.container.Composite,
     /**
      * create a page for the View Tab with the given title
-     * 
+     *
      * @param vizWidget {Widget} visualization widget to embedd
      */
-    construct : function(cfg,buttonClass,layout,getFormData) {        
+    construct : function(cfg,buttonClass,layout,getFormData) {
         /* using syntax trick to not get a warning for translating
            a variable */
         this.base(arguments, layout);
@@ -42,7 +42,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     }
                     break;
             }
-        },this);                 
+        },this);
     },
     events: {
         actionResponse: 'qx.event.type.Data',
@@ -82,7 +82,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         this._addUploadButton(cfg,btCfg,getFormData);
                         break;
                     default:
-                        this.debug('Invalid execute action:' + btCfg.action); 
+                        this.debug('Invalid execute action:' + btCfg.action);
                 }
                 if (button == null){
                     return;
@@ -98,8 +98,8 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                     this.tr("The form can only be submitted when all data fields have valid content.")
                                 );
                                 return;
-                            } 
-                            var key = btCfg.key;                           
+                            }
+                            var key = btCfg.key;
                             var that = this;
                             var asyncCall = function(){
                                 callbackery.data.Server.getInstance().callAsyncSmartBusy(function(ret){
@@ -130,9 +130,9 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                     this.tr("The form can only be submitted when all data fields have valid content.")
                                 );
                                 return;
-                            } 
-                            var key = btCfg.key;  
-                            var that = this;                           
+                            }
+                            var key = btCfg.key;
+                            var that = this;
                             callbackery.data.Server.getInstance().callAsyncSmart(function(cookie){
                                 var iframe = new qx.ui.embed.Iframe().set({
                                     width: 100,
@@ -154,7 +154,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                             that['tr'](response.exception.message) + " ("+ response.exception.code +")"
                                         );
                                     }
-                                    that.getApplicationRoot().remove(iframe);        
+                                    that.getApplicationRoot().remove(iframe);
                                 });
                                 iframe.setSource(
                                     'download'
@@ -175,11 +175,11 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                 // wait for stuff to happen befor we rush into
                                 // disposing the popup
                                 qx.event.Timer.once(function(){
-                                    this.getApplicationRoot().remove(popup); 
+                                    this.getApplicationRoot().remove(popup);
                                     popup.dispose();
                                     this.fireEvent('popupClosed');
                                 },this,100);
-                                if (!(btnCfg.options && btnCfg.options.noReload)){
+                                if (!(btCfg.options && btCfg.options.noReload)){
                                     this.fireDataEvent('actionResponse',{action: 'reload'});
                                 }
                             },this);
@@ -191,7 +191,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                             break;
 
                         default:
-                            this.debug('Invalid execute action:' + btCfg.action); 
+                            this.debug('Invalid execute action:' + btCfg.action);
                     }
                 },this);
             },this);
@@ -217,10 +217,10 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         this.tr("Validation Error"),
                         this.tr("The form can only be submitted when all data fields have valid content.")
                     );
-                } 
+                }
             });
             file.addListener('changeFileName',function(e){
-                var formData = getFormData(); 
+                var formData = getFormData();
                 if(formData && e.getData() !='') {
                     form.setParameter('formData',qx.lang.Json.stringify(formData));
                     // console.log(file.getFileName(),file.getFileSize());
@@ -233,7 +233,18 @@ qx.Class.define("callbackery.ui.plugin.Action", {
 
             form.addListener('completed',function(e) {
                 form.clear();
-                var response = qx.lang.Json.parse(form.getIframeTextContent());
+                var response = {};
+                try {
+                    response = qx.lang.Json.parse(form.getIframeTextContent());
+                }
+                catch(e){
+                    response = {
+                        exception: {
+                            message: e.message,
+                            code: 99999
+                        }
+                    };
+                }
                 if (response.exception){
                     callbackery.ui.MsgBox.getInstance().error(
                         this.tr("Upload Exception"),
@@ -241,7 +252,9 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     );
                     return;
                 }
-                this.fireDataEvent('actionResponse',response || {});
+                if (response.action){
+                    this.fireDataEvent('actionResponse',response.action || {});
+                }
             },this);
 
         }
