@@ -87,14 +87,19 @@ qx.Class.define('callbackery.ui.plugin.Table', {
                     }
                 },this);
             },this);
+            var that = this;
             model.addListener('dataChanged',function(e){
-                // it seems we get this event a little early, set the selection
-                // once all pending action has ceassed to be
-                // I guess this is a qx bug ...  dataChanged should
-                // only fire once model actuall HAS new data.
-                window.setTimeout(function(){
-                    selectionModel.setSelectionInterval(0,0);
-                },500);
+                // it seems that dataChanged is thrown as the model data
+                // is a bit early
+                // deferre the action until the thread is done
+                new qx.util.DeferredCall(function(){
+                    selectionModel.resetSelection();
+                    this.setSelection({});
+                },this).schedule();
+            },this);
+
+            this.addListener('appear',function(e){
+                model.reloadData();
             });
             this._form.addListener('changeData',function(e){
                 model.setFormData(e.getData());
@@ -102,9 +107,7 @@ qx.Class.define('callbackery.ui.plugin.Table', {
                     model.reloadData();
                 }
             },this);
-            this._action.addListener('popupClosed',function(e){
-                model.reloadData();
-            });
+
             this._action.addListener('actionResponse',function(e){
                 var data = e.getData();
                 switch (data.action){
@@ -114,7 +117,7 @@ qx.Class.define('callbackery.ui.plugin.Table', {
                         break;
                 }
             });
-            this.add(table,{flex: 1});
+            this.add(table, {flex: 1});
         }
     }
 });
